==> haskell-colour-2.3.3-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-colour.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: colour
version: 2.3.3
id: colour-2.3.3-1clKnMqHWhQAElTFd8Ydyp
key: colour-2.3.3-1clKnMqHWhQAElTFd8Ydyp
license: MIT
maintainer: Russell O'\''Connor <roconnor@theorem.ca>
homepage: http://www.haskell.org/haskellwiki/Colour
synopsis: A model for human colour/color perception
description:
    This package provides a data type for colours and transparency.
    Colours can be blended and composed.
    Various colour spaces are supported.
    A module of colour names ("Data.Colour.Names") is provided.
category: data, graphics
author: Russell O'\''Connor
exposed: True
exposed-modules:
    Data.Colour Data.Colour.SRGB Data.Colour.SRGB.Linear
    Data.Colour.CIE Data.Colour.CIE.Illuminant Data.Colour.RGBSpace
    Data.Colour.RGBSpace.HSL Data.Colour.RGBSpace.HSV Data.Colour.Names
hidden-modules: Data.Colour.Internal Data.Colour.Chan
                Data.Colour.RGB Data.Colour.Matrix Data.Colour.CIE.Chromaticity
abi: 5886d23853f4942829c14a24664cc76b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/colour-2.3.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/colour-2.3.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/colour-2.3.3
hs-libraries: HScolour-2.3.3-1clKnMqHWhQAElTFd8Ydyp
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-colour/html/colour.haddock
haddock-html: /usr/share/doc/haskell-colour/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-colour-2.3.3-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-colour.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: colour
version: 2.3.3
id: colour-2.3.3-7zspnmhVLMd3uThUzy60rY
key: colour-2.3.3-7zspnmhVLMd3uThUzy60rY
license: MIT
maintainer: Russell O'\''Connor <roconnor@theorem.ca>
homepage: http://www.haskell.org/haskellwiki/Colour
synopsis: A model for human colour/color perception
description:
    This package provides a data type for colours and transparency.
    Colours can be blended and composed.
    Various colour spaces are supported.
    A module of colour names ("Data.Colour.Names") is provided.
category: data, graphics
author: Russell O'\''Connor
exposed: True
exposed-modules:
    Data.Colour Data.Colour.SRGB Data.Colour.SRGB.Linear
    Data.Colour.CIE Data.Colour.CIE.Illuminant Data.Colour.RGBSpace
    Data.Colour.RGBSpace.HSL Data.Colour.RGBSpace.HSV Data.Colour.Names
hidden-modules: Data.Colour.Internal Data.Colour.Chan
                Data.Colour.RGB Data.Colour.Matrix Data.Colour.CIE.Chromaticity
abi: 72c0bc8e962b4ff6ace27e88ad71aef3
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/colour-2.3.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/colour-2.3.3
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/colour-2.3.3
hs-libraries: HScolour-2.3.3-7zspnmhVLMd3uThUzy60rY
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-colour/html/colour.haddock
haddock-html: /usr/share/doc/haskell-colour/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
